@@ -18,7 +18,7 @@ LINK = (
 s3 = boto3.resource(
     's3',
     region_name=cfg('amazon.region'),
-    aws_access_key_id=cfg('amazon.key'),
+    aws_access_key_id=cfg('amazon.id'),
     aws_secret_access_key=cfg('amazon.secret'),
 )
 s3client = s3.meta.client
@@ -27,7 +27,7 @@ s3client = s3.meta.client
 def upload_file(
     file,
     bucket=cfg('amazon.bucket'),
-    directory=cfg('amazon.directory'),
+    directory=cfg('mode').lower(),
     file_type=None,
 ):
     """ Upload file """
